﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace GrafickyEditor
{
    public partial class Form1 : Form
    {
        private GraphicalObject current = null;
        private List<GraphicalObject> objects = new List<GraphicalObject>();
        public Form1()
        {
            InitializeComponent();
            pictureBox1.Image = new Bitmap(pictureBox1.Width, pictureBox1.Height);
        }

        private void novyToolStripMenuItem_Click(object sender, EventArgs e)
        {
            objects = new List<GraphicalObject>();
            clearImage();
            current = null;
            caraToolStripMenuItem.Checked = false;
            obdelnikToolStripMenuItem.Checked = false;
            elipsaToolStripMenuItem.Checked = false;
        }

        private void clearImage()
        {
            using (Graphics g = Graphics.FromImage(pictureBox1.Image))
            {
                g.FillRectangle(Brushes.White, 0, 0, 
                    pictureBox1.Width, pictureBox1.Height);
            }
        }

        private void konecToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void caraToolStripMenuItem_Click(object sender, EventArgs e)
        {
            caraToolStripMenuItem.Checked = true;
            elipsaToolStripMenuItem.Checked = false;
            obdelnikToolStripMenuItem.Checked = false;
        }

        private void elipsaToolStripMenuItem_Click(object sender, EventArgs e)
        {
            elipsaToolStripMenuItem.Checked = true;
            caraToolStripMenuItem.Checked = false;
            obdelnikToolStripMenuItem.Checked = false;
        }

        private void obdelnikToolStripMenuItem_Click(object sender, EventArgs e)
        {
            obdelnikToolStripMenuItem.Checked = true;
            caraToolStripMenuItem.Checked = false;
            elipsaToolStripMenuItem.Checked = false;
        }

        private void pictureBox1_MouseDown(object sender, MouseEventArgs e)
        {
            current = new GraphicalObject();
            if (caraToolStripMenuItem.Checked)
            {
                current.kind = Kind.Cara;
            }
            if(obdelnikToolStripMenuItem.Checked)
            {
                current.kind = Kind.Obdelnik;
            }
            if(elipsaToolStripMenuItem.Checked)
            {
                current.kind = Kind.Elipsa;
            }
            if(current.kind == Kind.None)
            {
                return;
            }
            current.x = e.X;
            current.y = e.Y;
            objects.Add(current);
        }

        private void pictureBox1_MouseMove(object sender, MouseEventArgs e)
        {
            if (current != null)
            {
                clearObject(current);
                current.x1 = e.X;
                current.y1 = e.Y;
                pictureBox1.Refresh();
            }
            Refresh();
            positionStatus.Text = e.X + "," + e.Y;
        }

        private void clearObject(GraphicalObject current)
        {
            Pen pen = new Pen(pictureBox1.BackColor);
            switch(current.kind)
            {
                case Kind.Cara:
                    drawLine(current, pen);
                    break;
                case Kind.Elipsa:
                    drawEllipse(current, pen);
                    break;
                case Kind.Obdelnik:
                    drawRectangle(current, pen);
                    break;
                default:break;
            }
        }

        private void drawRectangle(GraphicalObject current, Pen pen)
        {
            int x = Math.Min(current.x, current.x1);
            int dx = Math.Max(current.x, current.x1) - x;
            int y = Math.Min(current.y, current.y1);
            int dy = Math.Max(current.y, current.y1) - y;
            using (Graphics g = Graphics.FromImage(pictureBox1.Image))
            {
                g.DrawRectangle(pen, x, y, dx, dy);
            }
        }

        private void drawEllipse(GraphicalObject current, Pen pen)
        {
            int x = Math.Min(current.x, current.x1);
            int dx = Math.Max(current.x, current.x1) - x;
            int y = Math.Min(current.y, current.y1);
            int dy = Math.Max(current.y, current.y1) - y;
            using (Graphics g = Graphics.FromImage(pictureBox1.Image))
            {
                g.DrawEllipse(pen, x, y, dx, dy);
            }
        }

        private void drawLine(GraphicalObject current, Pen pen)
        {
            int x = current.x;
            int y = current.y;
            int x1 = current.x1;
            int y1 = current.y1;
            using (Graphics g = Graphics.FromImage(pictureBox1.Image))
            {
                g.DrawLine(pen, x, y, x1, y1);
            }
        }

        private void pictureBox1_MouseUp(object sender, MouseEventArgs e)
        {
            current.x1 = e.X;
            current.y1 = e.Y;
            pictureBox1.Refresh();
            Refresh();
            current = null;
        }

        private void pictureBox1_Paint(object sender, PaintEventArgs e)
        {
            Pen pen = new Pen(Color.Black);
            foreach (GraphicalObject obj in objects)
            {
                switch(obj.kind)
                {
                    case Kind.Cara:
                        drawLine(obj, pen);
                        break;
                    case Kind.Elipsa:
                        drawEllipse(obj, pen);
                        break;
                    case Kind.Obdelnik:
                        drawRectangle(obj, pen);
                        break;
                    default:break;
                        
                }
            }
        }

        private void pictureBox1_Resize(object sender, EventArgs e)
        {
            pictureBox1.Width = Size.Width;
            pictureBox1.Height = Size.Height - statusStrip1.Height; ;
            pictureBox1.Image = new Bitmap(pictureBox1.Width, pictureBox1.Height);
            clearImage();
            pictureBox1.Refresh();
            Refresh();
        }
    }
}
